<?php
/*
	Functions for displaying various menu contents
	@since 0.1

	PixoPoint Menu Plugin
	Copyright (c) 2009 PixoPoint Web Development

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as
	published by the Free Software Foundation.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

*/


/**
 * Displays the 'Pages' option
 * @since 0.1
 */
function pixopoint_menu_pages() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );

	switch ( $pixopoint_menuoptions['pixopoint_menu_depthpages'] ) { // Sets nesting of pages
		case 'Top level only' : $pixopoint_menu_depthpagesecho = '&depth=1'; break;
		case 'No nesting' :  $pixopoint_menu_depthpagesecho = '&depth=-1'; break;
		case '1 level of children': $pixopoint_menu_depthpagesecho = '&depth=2'; break;
		case '2 levels of children': $pixopoint_menu_depthpagesecho = '&depth=3'; break;
		case 'Infinite': $pixopoint_menu_depthpagesecho = '&depth=0'; break;
	}
	if ( is_page() AND get_post_custom_values( $pixopoint_menuoptions['pixopoint_menu_pagestitle'] ) != '' )
		$pages_class=' class="pages current_page_parent current_page_item"';
	else
		$pages_class=' class="pages haschildren"';
	// For putting the pages into a single dropdown
	if ( $pixopoint_menuoptions['pixopoint_menu_pages_singledropdown'] == 'on' ) {
		echo '<li' . $pages_class . '><a href="';
		if ( $pixopoint_menuoptions['pixopoint_menu_pagesurl'] != '')
			echo $pixopoint_menuoptions['pixopoint_menu_pagesurl'];
		else
			echo '#';
		echo '">' . esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_pagestitle'] ) ) . '</a><ul>';
	}
	// Sets page order
	switch ( $pixopoint_menuoptions['pixopoint_menu_pageorder'] ){
		case 'Normal' : $pixopoint_menu_pageorderecho = 'sort_column=menu_order&'; break;
		case 'Ascending Name' : $pixopoint_menu_pageorderecho = 'sort_column=post_title&sort_order=asc&'; break;
		case 'Descending Name' : $pixopoint_menu_pageorderecho = 'sort_column=post_title&sort_order=desc&'; break;
		case '' : $pixopoint_menu_pageorderecho = 'sort_column=menu_order&'; break;
	}
	// Displays the actual pages
	echo ereg_replace(
		"\"><a [/\?a-zA-Z0-9\-\.\:\"\=\_ >]+</a>([\t\n]+)<ul"," haschildren\\0",
		wp_list_pages(
			'title_li=&' .
			$pixopoint_menu_pageorderecho .
			esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_includeexcludepages'] ) ) .
			'=' .
			esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_excludepages'] ) ) .
			'&echo=0' .
			esc_attr( stripcslashes( $pixopoint_menu_depthpagesecho ) )
		)
	),
	"";
	// For putting the pages into a sinle dropdown
	if ( $pixopoint_menuoptions['pixopoint_menu_pages_singledropdown'] == 'on' ) {
		echo '</ul></li>';
	}
}


/**
 * Displays the 'Categories' option
 * @since 0.1
 */
function pixopoint_menu_category() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	if ( $pixopoint_menuoptions['pixopoint_menu_categorycount'] == 'on')
		$pixopoint_menu_categorycount = 'show_count=1'; // Adds category count
	if ( $pixopoint_menuoptions['pixopoint_menu_categoryshowempty'] == 'on')
		$pixopoint_menu_categoryshowempty = '&hide_empty=0'; // Hides empty categories
	// Sets category nesting
	switch ( $pixopoint_menuoptions['pixopoint_menu_depthcategories'] ) {
		case 'Top level only' : $pixopoint_menu_depthcategoriesecho = '&depth=1'; break;
		case 'No nesting' : $pixopoint_menu_depthcategoriesecho = '&depth=-1'; break;
		case '1 level of children' : $pixopoint_menu_depthcategoriesecho = '&depth=2'; break;
		case '2 levels of children' : $pixopoint_menu_depthcategoriesecho = '&depth=3'; break;
		case 'Infinite' : $pixopoint_menu_depthcategoriesecho = '&depth=0'; break;
	}
	// Sets category order
	switch ( $pixopoint_menuoptions['pixopoint_menu_categoryorder'] ) {
		case 'My Category Order plugin' : $pixopoint_menu_categoryorderecho = '&orderby=order'; break;
		case 'Ascending ID #' : $pixopoint_menu_categoryorderecho = '&orderby=id&order=ASC'; break;
		case 'Descending ID #' : $pixopoint_menu_categoryorderecho = '&orderby=id&order=DESC'; break;
		case 'Ascending Name' : $pixopoint_menu_categoryorderecho = '&orderby=name&order=ASC'; break;
		case 'Descending Name' : $pixopoint_menu_categoryorderecho = '&orderby=name&order=DESC'; break;
	}
	// If single dropdown is set, then adds the extra HTML
	if ( $pixopoint_menuoptions['pixopoint_menu_categories_singledropdown'] == 'on') {
		// If on a category page, then sets the 'current_page_item' class
		if ( is_category() )
			$pixopoint_menu_class=' class="categories current_page_parent current_page_item haschildren"';
		else
			$pixopoint_menu_class = ' class="categories haschildren"';
		echo '<li' . $pixopoint_menu_class . '><a href="';
		// If URL for category is set, then adds it, otherwise is left as a dead link
		if ( $pixopoint_menuoptions['pixopoint_menu_categoriesurl'] != '')
			echo esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_categoriesurl'] ) );
		else
			echo '#';
		// Adds the 'Categories' title
		echo '">' . esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_categoriestitle'] ) ) . '</a><ul>';
	}
	// Displays the actual categories
	echo implode(
		"</a><ul",
		explode(
			"</a><ul",
			str_replace(
				"\t",
				'',
				wp_list_categories(
					'title_li=' .
					esc_attr( stripcslashes( $pixopoint_menu_categoryshowempty ) ) .
					'&' .
					esc_attr( stripcslashes( $pixopoint_menu_categorycount ) ) .
					'&' .
					esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_includeexcludecategories'] ) ) .
					'=' .
					$pixopoint_menuoptions['pixopoint_menu_excludecategories'] .
					'&echo=0' .
					esc_attr( stripcslashes( $pixopoint_menu_categoryorderecho ) ) .
					esc_attr( stripcslashes( $pixopoint_menu_depthcategoriesecho ) )
				)
			)
		)
	);
	// If single dropdown is set, then adds the extra HTML
	if ( $pixopoint_menuoptions['pixopoint_menu_categories_singledropdown'] == 'on' )
		echo '</ul></li>';
}


/**
 * Displays the 'Categories' option when the 'Nest posts' option is used ... note: code mostly written by itsanderson
 * @since 0.1
 */
function pixopoint_menu_categories_and_posts($parent = 0, $depth = 0) {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	if ( $pixopoint_menuoptions['pixopoint_menu_categoryshowempty'] == 'on' )
		$pixopoint_menu_categoryshowempty = '&hide_empty=0';
	switch( $pixopoint_menuoptions['pixopoint_menu_depthcategories'] ) {
		case 'Top level only' : $pixopoint_menu_depthcategoriesecho=1; break;
		case 'No nesting' : $pixopoint_menu_depthcategoriesecho=-1; break;
		case '1 level of children' : $pixopoint_menu_depthcategoriesecho=2; break;
		case '2 levels of children' : $pixopoint_menu_depthcategoriesecho=3; break;
		case 'Infinite' : $pixopoint_menu_depthcategoriesecho=0; break;
	}
	switch( $pixopoint_menuoptions['pixopoint_menu_categoryorder'] ) {
		case 'My Category Order plugin' : $pixopoint_menu_categoryorderecho = '&orderby=order'; break;
		case 'Ascending ID #' : $pixopoint_menu_categoryorderecho = '&orderby=id&order=ASC'; break;
		case 'Descending ID #' : $pixopoint_menu_categoryorderecho = '&orderby=id&order=DESC'; break;
		case 'Ascending Name' : $pixopoint_menu_categoryorderecho = '&orderby=name&order=ASC'; break;
		case 'Descending Name' : $pixopoint_menu_categoryorderecho = '&orderby=name&order=DESC'; break;
	}
	$categories = get_categories(
		"child_of=$parent" .
		esc_attr( stripcslashes( $pixopoint_menu_categoryshowempty ) ) .
		'&' .
		esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_includeexcludecategories'] ) ) .
		'=' .
		esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_excludecategories'] ) ) .
		esc_attr( stripcslashes( $pixopoint_menu_categoryorderecho ) )
	);
	$posts = ($parent ? get_posts( 'category=$parent&numberposts=' .  $pixopoint_menuoptions['pixopoint_menu_categorypostslimit'] ) : array());
	if ( $parent == 0 )
		if ( is_category() ) { $pixopoint_menu_class=' class="current_page_parent current_page_item"'; }
	if ( (count($categories) AND ( $pixopoint_menu_depthcategoriesecho < 1 || $pixopoint_menu_depthcategoriesecho > $depth ) ) || count($posts) ) {
		if ( $parent != 0 )
			echo '<ul>'; // Remove if statement to create single dropdown
		if ( $pixopoint_menu_depthcategoriesecho < 1 || $pixopoint_menu_depthcategoriesecho > $depth ) {
			foreach ( $categories as $category ) {
				if ( $category->parent == $parent ) {
					echo '<li class="cat-item cat-item-' .
						esc_attr( stripcslashes( $category->cat_ID ) ).
						'"><a href="' .
						esc_attr( stripcslashes( get_category_link($category->cat_ID) ) ).
						'" title="View all posts filed under ' .
						esc_attr( stripcslashes( $category->cat_name ) ) .
						'">' .
						esc_attr( stripcslashes( $category->cat_name ) ).
					'</a>';
					if ( $pixopoint_menu_depthcategoriesecho < 1 || $pixopoint_menu_depthcategoriesecho >= $depth )
						pixopoint_menu_categories_and_posts( $category->cat_ID, $depth+1 );
					echo '</li>';
				}
			}
		}
		foreach ( $posts as $current_post ) {
			echo '<li class="post-item post-item-' .
				$current_post->ID .
				'"><a href="' .
				get_permalink($current_post->ID) .
				'" title="' .
				$current_post->post_title .
				'">' .
				$current_post->post_title .
			'</a></li>';
		}
		if ( $parent != 0 )
			echo '</ul>'; // Remove if statement to create single dropdown
	}
}


/**
 * Display the 'Home' option
 * @since 0.1
 */
function pixopoint_menu_home() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	// if on the home page, then add 'current-page-item' class
	if ( is_front_page() )
		$pixopoint_menu_class = ' class="current_page_item home"';
	else
		$pixopoint_menu_class = ' class="home"';
	// Add the HTML
	echo '<li' . $pixopoint_menu_class . '><a href="';
	if ( $pixopoint_menuoptions['pixopoint_menu_homeurl'] != '' )
		echo esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_homeurl'] ) ); // If URL set, then use that
	else
		echo bloginfo('url') . '/'; // If no URL set, then use built in one
	echo '">' . esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_hometitle'] ) ) . '</a></li>';
}


/**
 * Display the 'Links' options
 * @todo Improve effiency by combining into single function
 * @since 0.1
 */
function pixopoint_menu_blogroll() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	wp_list_bookmarks( 'title_li=&categorize=0' );
}
function pixopoint_menu_blogrolldropdown() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	echo '<li class="links haschildren"><a href="';
	if ( $pixopoint_menuoptions['pixopoint_menu_blogrollurl'] != '' )
		echo esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_blogrollurl'] ) );
	echo '">' . esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_blogrolltitle'] ) ) . '</a> <ul>';
	pixopoint_menu_blogroll();
	echo '</ul></li>';
}
function pixopoint_menu_blogrollcategories() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	wp_list_bookmarks( 'title_li=&title_before=<a href="">&title_after=</a>&categorize=1&before=<li>&after=</li>&show_images=0&show_description=0&orderby=url' );
}
function pixopoint_menu_blogrollcategoriesdropdown() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	echo '<li><a href="';
	if ( $pixopoint_menuoptions['pixopoint_menu_blogrollurl'] != '' )
		echo esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_blogrollurl'] ) );
	else
		echo '#';
	echo '">' . esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_blogrolltitle'] ) ) . '</a> <ul>';
	pixopoint_menu_blogrollcategories();
	echo '</ul></li>';
}


/**
 * Display the 'Archives' options
 * @todo Improve effiency by combining into single function
 * @since 0.1
 */
function pixopoint_menu_archivesmonths() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	wp_get_archives( 'type=monthly' );
}
function pixopoint_menu_archivesyears() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	wp_get_archives( 'type=yearly' );
}
function pixopoint_menu_archivesyearsandmonths() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	// Buffering months archives
	ob_start();
	pixopoint_menu_archivesmonths();
	$archives_monthly = ob_get_contents();
	ob_end_clean();
	$archives_monthly = explode( '</li>', $archives_monthly );
	foreach( $archives_monthly as $key => $value ) {
		$year[$key] = substr( $archives_monthly[$key], -9,-4 );
	}
	// Buffering years archives
	ob_start();
	pixopoint_menu_archivesyears();
	$archives_yearly = ob_get_contents();
	ob_end_clean();
	$archives_yearly = explode( '</li>', $archives_yearly );
	// Display years and months
	foreach ( $year as $key => $value ) {
		if ( $year[$key] != $year[$key-1] ) {
			foreach ( $archives_yearly as $key3 => $value3 ) {
				$archives_yearly2[$key3] = substr( $archives_yearly[$key3], -8,-4 );
				if ( $year[$key] == $archives_yearly2[$key3] )
					echo esc_attr( stripcslashes( $archives_yearly[$key3] ) );
			}
			if ( $archives_monthly[0] != '' ) {
				if ( $year[$key] != '' ) {echo '<ul>';}
				foreach ( $archives_monthly as $key2 => $value2 ) {
					$length = strlen($archives_monthly[$key2]);
					$archivessnipped[$key2] = substr($archives_monthly[$key2], 0,$length-9 );
					$archivessnipped2[$key2] = substr($archives_monthly[$key2], $length-8,4 );
					if ( $archivessnipped2[$key2] == $year[$key] ) {
						if ( $archivessnipped[$key2] != '' )
							echo esc_attr( stripcslashes( $archivessnipped[$key2] ) ) . '</a></li>';
					}
				}
				if ( $year[$key] != '' )
					echo '</ul></li>';
			}
		}
	}
}
function pixopoint_menu_archivesmonthsdropdown() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	if ( is_month() )
		$pixopoint_menu_class=' class="archives current_page_parent current_page_item"';
	else
		$pixopoint_menu_class=' class="archives haschildren"';
	echo '<li' . $pixopoint_menu_class . '><a href="';
	if ( $pixopoint_menuoptions['pixopoint_menu_archivesurl'] != '' )
		echo esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_archivesurl'] ) );
	echo '">' . esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_archivestitle'] ) ) . '</a><ul>';
	pixopoint_menu_archivesmonths();
	echo '</ul></li>';
}
function pixopoint_menu_archivesyearsdropdown() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	if ( is_year() )
		$pixopoint_menu_class = ' class="archives current_page_parent current_page_item"';
	else
		$pixopoint_menu_class = ' class="archives haschildren"';
	echo '<li' . $pixopoint_menu_class . '><a href="';
	if ( $pixopoint_menuoptions['pixopoint_menu_archivesurl'] != '' )
		echo esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_archivesurl'] ) );
	echo '">' . esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_archivestitle'] ) ) . '</a><ul>';
	pixopoint_menu_archivesyears();
	echo '</ul></li>';
}
function pixopoint_menu_archivesyearsandmonthsdropdown() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	if ( is_year() || is_month() )
		$pixopoint_menu_class = ' class="archives current_page_parent current_page_item"';
	else
		$pixopoint_menu_class = ' class="archives haschildren"';
	echo '<li' . $pixopoint_menu_class . '><a href="';
	if ( $pixopoint_menuoptions['pixopoint_menu_archivesurl'] != '' )
		echo esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_archivesurl'] ) );
	echo '">' . esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_archivestitle'] ) ) . '</a><ul>';
	pixopoint_menu_archivesyearsandmonths();
	echo '</ul></li>';
}


/**
 * Display the 'Recent Comments' option
 * @since 0.1
 */
function pixopoint_menu_recentcomments() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	echo '<li class="recentcomments haschildren"><a href="';
	if ( $pixopoint_menuoptions['pixopoint_menu_recentcommentsurl'] != '' )
		echo esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_recentcommentsurl'] ) );
	echo '">' . $pixopoint_menuoptions['pixopoint_menu_recentcommentstitle'] . '</a>';
	global $wpdb;
	$sql = "SELECT DISTINCT ID, post_title, post_password, comment_ID, comment_post_ID, comment_author, comment_date_gmt, comment_approved, comment_type,comment_author_url, SUBSTRING(comment_content,1,30) AS com_excerpt FROM $wpdb->comments LEFT OUTER JOIN $wpdb->posts ON ($wpdb->comments.comment_post_ID = $wpdb->posts.ID) WHERE comment_approved = '1' AND comment_type = '' AND post_password = '' ORDER BY comment_date_gmt DESC LIMIT 10".$pixopoint_menuoptions['pixopoint_menu_recentcommentsnumber'];
	$comments = $wpdb->get_results( $sql );
	$output = $pre_HTML;
	$output .= "<ul>";
	foreach ( $comments as $comment ) {
		$output .= "<li><a href=\"" . get_permalink( $comment->ID ) . "#comment-" . $comment->comment_ID . "\" title=\"on " . $comment->post_title . "\">" . strip_tags( $comment->comment_author ) . ":" . " " . strip_tags( $comment->com_excerpt ) . "</a></li>";
	}
	$output .= "</ul>";
	$output .= $post_HTML;
	echo $output;
	echo '</li>';
}

	
/**
 * Display the 'Custom Code 1' option
 * @since 0.1
 */
function pixopoint_menu_custom() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	// Check if to be displayed to non-logged in users or not
	// This functionality is not currently available, but support will be added in a separate plugin in the future
	if ( $pixopoint_menuoptions['pixopoint_menu_customcodelogged1'] == 'on' ) {
		// Check if logged in
		if ( is_user_logged_in() ) {
			if ( !function_exists('pixopoint_mln_custom1php' ) )
				echo $pixopoint_menuoptions['pixopoint_menu_custommenu']; // Check that custom PHP mode is not on
			else
				pixopoint_mln_custom1php(); // Else load custom PHP
		}
	}
	// Else display to everyone
	else {
		if ( !function_exists( 'pixopoint_mln_custom1php' ) )
			echo $pixopoint_menuoptions['pixopoint_menu_custommenu']; // Check that custom PHP mode is not on
		else
			pixopoint_mln_custom1php(); // Else load custom PHP
	}
}


/**
 * Display the 'Custom Code 2' option
 * @since 0.1
 */
function pixopoint_menu_custom2() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	// Check if to be displayed to non-logged in users or not
	// This functionality is not currently available, but support will be added in a separate plugin in the future
	if ( $pixopoint_menuoptions['pixopoint_menu_customcodelogged2'] == 'on' ) {
		// Check if logged in
		if ( is_user_logged_in() ) {
			if ( !function_exists('pixopoint_mln_custom2php' ) )
				echo $pixopoint_menuoptions['pixopoint_menu_custommenu2']; // Check that custom PHP mode is not on
			else
				pixopoint_mln_custom2php(); // Else load custom PHP
		}
	}
	else {
		if ( !function_exists('pixopoint_mln_custom2php' ) )
			echo $pixopoint_menuoptions['pixopoint_menu_custommenu2']; // Check that custom PHP mode is not on
		else
			pixopoint_mln_custom2php(); // Else load custom PHP
	}
}


/**
 * Display the 'Custom Code 3' option
 *
 * @package WordPress
 * @since 0.1
 *
 */
function pixopoint_menu_custom3() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	// Check if to be displayed to non-logged in users or not
	if ( $pixopoint_menuoptions['pixopoint_menu_customcodelogged3'] == 'on' ) {
		// Check if logged in
		if ( is_user_logged_in() ) {
			if ( !function_exists( 'pixopoint_mln_custom3php' ) )
				echo $pixopoint_menuoptions['pixopoint_menu_custommenu3']; // Check that custom PHP mode is not on
			else
				pixopoint_mln_custom3php(); // Else load custom PHP
		}
	}
	// Else display to everyone
	else {
		if ( !function_exists( 'pixopoint_mln_custom3php' ) )
			echo $pixopoint_menuoptions['pixopoint_menu_custommenu3']; // Check that custom PHP mode is not on
		else
			pixopoint_mln_custom3php(); // Else load custom PHP
	}
}


/**
 * Display the 'Custom Code 4' option
 * @since 0.1
 */
function pixopoint_menu_custom4() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	// Check if to be displayed to non-logged in users or not
	if ( $pixopoint_menuoptions['pixopoint_menu_customcodelogged4'] == 'on') {
		// Check if logged in
		if ( is_user_logged_in() ) {
			if ( !function_exists('pixopoint_mln_custom4php' ) )
				echo $pixopoint_menuoptions['pixopoint_menu_custommenu4']; // Check that custom PHP mode is not on
			else
				pixopoint_mln_custom4php(); // Else load custom PHP
		}
	}
	// Else display to everyone
	else {
		if ( !function_exists('pixopoint_mln_custom4php' ) )
			echo $pixopoint_menuoptions['pixopoint_menu_custommenu4']; // Check that custom PHP mode is not on
		else
			pixopoint_mln_custom4php(); // Else load custom PHP
	}
}


/**
 * Display the 'Recent Posts' option
 * @since 0.1
 */
function pixopoint_menu_recentposts() {
	$pixopoint_menuoptions = get_option( 'pixopoint_menuoptions' );
	echo '<li><a href="';
	if ( $pixopoint_menuoptions['pixopoint_menu_recentpostsurl'] != '' )
		echo esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_recentpostsurl'] ) );
	else
		echo '#';
	echo '">';
	echo esc_attr( stripcslashes( $pixopoint_menuoptions['pixopoint_menu_recentpoststitle'] ) ) . '</a><ul>';
	query_posts( 'showposts=' . $pixopoint_menuoptions['pixopoint_menu_recentpostsnumber'] );
	while (have_posts()) {
		the_post();
		echo '<li><a href="';
		the_permalink();
		echo '">';
		the_title();
		echo '</a></li>';
	}
	wp_reset_query();
	echo '</ul></li>';
}


?>
