<?php
/*
	Loads a bunch of stuff common to both admin and core (front-end)
	@since 0.7

	PixoPoint Menu Plugin
	Copyright (c) 2009 PixoPoint Web Development

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as
	published by the Free Software Foundation.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

*/


/**
 * Define a bunch of paths and URLs for use throughout the plugin
 * @since 0.7
 */
define( 'PIXOPOINT_MENU_DIR', WP_PLUGIN_DIR . '/pixopoint-menu/' ); // URL for the plugins folder
define( 'PIXOPOINT_MENU_URL', WP_PLUGIN_URL . '/pixopoint-menu/' ); // Path to  the plugins folder
define( 'PIXOPOINT_MENU_URL_IMAGES', PIXOPOINT_MENU_URL . 'images/' ); // URL for the images folder
define( 'PIXOPOINT_MENU_URL_SCRIPTS', PIXOPOINT_MENU_URL . 'scripts/' ); // URL for the scripts folder
define( 'PIXOPOINT_MENU_URL_LANGUAGES', PIXOPOINT_MENU_URL . 'languages/' ); // URL for the languages folder
define( 'PIXOPOINT_MENU_DIR_ADMIN', PIXOPOINT_MENU_DIR . 'admin/' ); // Path to the admin folder
define( 'PIXOPOINT_MENU_URL_ADMIN', PIXOPOINT_MENU_URL . 'admin/' ); // URL for the admin folder
define( 'PIXOPOINT_MENU_DIR_CORE', PIXOPOINT_MENU_DIR . 'core/' ); // Path to the core folder
define( 'PIXOPOINT_MENU_URL_CORE', PIXOPOINT_MENU_URL . 'core/' ); // URL for the core folder
define( 'PIXOPOINT_MENU_DIR_LIBRARY', PIXOPOINT_MENU_DIR . 'library/' ); // Path to the library folder
define( 'PIXOPOINT_MENU_URL_LIBRARY', PIXOPOINT_MENU_URL . 'library/' ); // Path to the library folder
define( 'PIXOPOINT_MENU_LANGUAGE', 'pixopoint_menu_lang' ); // Setting the language string (used for translations)


/**
 * Add localization support
 * @since 0.1
 */
function pixopoint_menu_init() {
	load_plugin_textdomain ( PIXOPOINT_MENU_LANGUAGE, PIXOPOINT_MENU_URL_LANGUAGES );
}
add_action( 'init', 'pixopoint_menu_init' );


/**
 * Hooks for external plugins to add new menu items
 * Under development - may or may not work yet
 * @since 0.7
 */
function pixopoint_menu_sortablescripts() {do_action( 'pixopoint_menu_sortablescripts' );}
function pixopoint_menu_processhook() {
	global $set, $item, $sanitized_menucontents, $position;
	do_action( 'pixopoint_menu_processhook' );
}
function pixopoint_menu_itemhook() {
	global $set;
	do_action( 'pixopoint_menu_itemhook' );
}


/**
 * Strip out all but a select group of HTML tags
 * @since 0.1
 */
function pixopoint_allowed_html() {
	global $allowed_html;

	$allowed_html = array(
		'a'       => array(
			'href'      => array(),
			'title'     => array()
		),
		'div'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'span'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'id'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'p'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'h1'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'h2'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'h3'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'h4'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'h5'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'h6'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'table'      => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'code'      => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'pre'      => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'tr'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
			'td'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'th'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'thead'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'tfoot'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'ul'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'li'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'ol'     => array(
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'img'     => array(
			'src'      => array(),
			'style'      => array(),
			'class'      => array(),
			'id'         => array()
		),
		'br'     => array(),
		'em'     => array(),
		'i'      => array(),
		'strong' => array(),
		'b'      => array(),
		'u'      => array(),
		'font'   => array()
	);
}


?>
